@@ -1,10 +1,10 @@
 package Search::Query::Dialect::Native;
-use Moose;
+use Moo;
 extends 'Search::Query::Dialect';
 use Carp;
 use Data::Dump qw( dump );
 
-our $VERSION = '0.303';
+our $VERSION = '0.304';
 
 =head1 NAME
 
